==> library1.4.1.tar.bz2: library/domain/editform.php <==
<?php
///////////////////////////////////////////////////
//Карпухин Павел
//2010 (C)
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['domain-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
$button = $TEXT['btn_save'];
$action = "edit.php";
if(strlen($_GET['dom_id'])>5) {puterror($result2['skin'],$TEXT['error-domain6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['dom_id'] = rep($_GET['dom_id']);
$old_dom_id = $_GET['dom_id'];

$query10 = "SELECT * FROM `tbl_domain` WHERE `dom_id`='".$_GET['dom_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl13']); require_once "../utils/bottom_adm.php"; exit();}
   $result_dom = mysqli_fetch_array($result10);
   $domain = $result_dom['domain'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size=30 maxlength=30 type=text name=domain value='<?php echo $domain; ?>'></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=dom_id value='<?php echo $old_dom_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/domain/editform.php <==
<?php
///////////////////////////////////////////////////
//Карпухин Павел
//2010 (C)
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['domain-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
$button = $TEXT['btn_save'];
$action = "edit.php";
if(strlen($_GET['dom_id'])>5) {puterror($result2['skin'],$TEXT['error-domain6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['dom_id'] = rep($_GET['dom_id']);
$old_dom_id = $_GET['dom_id'];

$query10 = "SELECT * FROM `tbl_domain` WHERE `dom_id`='".$_GET['dom_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl13']); require_once "../utils/bottom_adm.php"; exit();}
   $result_dom = mysqli_fetch_array($result10);
   $domain = $result_dom['domain'];
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size="30" maxlength="30" type="text" name="domain" value="<?php echo $domain; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="dom_id" value="<?php echo $old_dom_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
